pub struct ArgsErrorWithInput { /* private fields */ }Expand description
An args parsing error, with input info, so that it can be formatted nicely
Implementations
Sourceimpl ArgsErrorWithInput
impl ArgsErrorWithInput
Sourcepub fn to_ariadne_report(&self) -> Report<'static, Range<usize>>
pub fn to_ariadne_report(&self) -> Report<'static, Range<usize>>
Returns an Ariadne report builder for this error.
The report uses std::ops::Range<usize> as the span type, suitable for
use with ariadne::Source::from(&self.flattened_args).
Sourcepub fn write_ariadne(&self, writer: impl Write) -> Result<()>
pub fn write_ariadne(&self, writer: impl Write) -> Result<()>
Writes the error as a pretty-printed Ariadne diagnostic to the given writer.
This creates a source from the flattened CLI arguments and renders the error report with source context.
Sourcepub fn to_ariadne_string(&self) -> String
pub fn to_ariadne_string(&self) -> String
Returns the error as a pretty-printed Ariadne diagnostic string.
This is a convenience method that calls write_ariadne
with an in-memory buffer.
Sourceimpl ArgsErrorWithInput
impl ArgsErrorWithInput
Sourcepub const fn is_help_request(&self) -> bool
pub const fn is_help_request(&self) -> bool
Returns true if this is a help request (not a real error)
Sourcepub fn shape_diagnostics(&self) -> Option<ShapeDiagnostics>
pub fn shape_diagnostics(&self) -> Option<ShapeDiagnostics>
Returns shape diagnostics if the error includes schema context.